==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetCampaignsRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCampaignsRequest(
    applicationId: __string,
    pageSize: Option[__string] = None,
    token: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest = {
    import GetCampaignsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .optionallyWith(
        pageSize.map(value => __string.unwrap(value): java.lang.String)
      )(_.pageSize)
      .optionallyWith(
        token.map(value => __string.unwrap(value): java.lang.String)
      )(_.token)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignsRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignsRequest.wrap(buildAwsValue())
}
object GetCampaignsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignsRequest =
      zio.aws.pinpoint.model.GetCampaignsRequest(
        applicationId,
        pageSize.map(value => value),
        token.map(value => value)
      )
    def applicationId: __string
    def pageSize: Option[__string]
    def token: Option[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getPageSize: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("token", token)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
  ) extends zio.aws.pinpoint.model.GetCampaignsRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val pageSize: Option[__string] = scala
      .Option(impl.pageSize())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
    override val token: Option[__string] = scala
      .Option(impl.token())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
  ): zio.aws.pinpoint.model.GetCampaignsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/GetCampaignsRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetCampaignsRequest(
    applicationId: __string,
    pageSize: Optional[__string] = Optional.Absent,
    token: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest = {
    import GetCampaignsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .optionallyWith(pageSize.map(value => value: java.lang.String))(
        _.pageSize
      )
      .optionallyWith(token.map(value => value: java.lang.String))(_.token)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignsRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignsRequest.wrap(buildAwsValue())
}
object GetCampaignsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignsRequest =
      zio.aws.pinpoint.model.GetCampaignsRequest(
        applicationId,
        pageSize.map(value => value),
        token.map(value => value)
      )
    def applicationId: __string
    def pageSize: Optional[__string]
    def token: Optional[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getPageSize: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("token", token)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
  ) extends zio.aws.pinpoint.model.GetCampaignsRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val pageSize: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.pageSize())
      .map(value => value: __string)
    override val token: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.token())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignsRequest
  ): zio.aws.pinpoint.model.GetCampaignsRequest.ReadOnly = new Wrapper(impl)
}
